@@ -1,3 +1,9 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
                           customfdialog.cpp  -  description
                              -------------------
@@ -17,22 +23,24 @@
 
 #include "customfdialog.h"
 #include "customfdialog.moc"
-#include <qimage.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qfileinfo.h>
 #include <qdir.h>
 #include <qdom.h>
 #include <qtextcodec.h>
-extern QImage LoadPict(QString fn, bool *gray = 0);
-extern bool loadText(QString nam, QString *Buffer);
-extern QPixmap loadIcon(QString nam);
+#include "sccombobox.h"
+#include "scribusstructs.h"
+#include "scslainforeader.h"
+#include "scimage.h"
+#include "util.h"
+
 extern QString DocDir;
 
 ImIconProvider::ImIconProvider(QWidget *pa) : QFileIconProvider(pa)
 {
 	fmts.clear();
-	QString tmp[] = {"eps", "gif", "png", "jpg", "jpeg", "xpm", "tif", "bmp", "pbm", "pgm", "ppm", "xbm", "xpm"};
+	QString tmp[] = {"eps", "gif", "png", "jpg", "jpeg", "xpm", "tif", "tiff", "bmp", "pbm", "pgm", "ppm", "xbm", "xpm", "psd"};
 	size_t array = sizeof(tmp) / sizeof(*tmp);
 	for (uint a = 0; a < array; ++a)
 		fmts += tmp[a];
@@ -105,6 +113,7 @@ void FDialogPreview::GenPreview(QString name)
 	updtPix();
 	int w = pixmap()->width();
 	int h = pixmap()->height();
+	bool mode = false;
 	QString ext = fi.extension(false).lower();
 	QStringList formats;
 	formats = QStringList::fromStrList(QImageIO::inputFormats());
@@ -113,6 +122,7 @@ void FDialogPreview::GenPreview(QString name)
 	formats.append("tif");
 	formats.append("tiff");
 #endif
+	formats.append("psd");
 	formats.append("eps");
 	formats.append("pdf");
 	formats.append("ps");
@@ -122,76 +132,114 @@ void FDialogPreview::GenPreview(QString name)
 	formats = QStringList::split( " ", allFormats );
 	if (formats.contains(ext))
 	{
-		QImage im = LoadPict(name);
-		if (!im.isNull())
+		ScImage im;
+		if (im.LoadPicture(name, "", 0, false, false, ScImage::Thumbnail, 72, &mode))
 		{
-			int ix = im.width();
-			int iy = im.height();
+			int ix,iy;
+			if ((im.imgInfo.exifDataValid) && (!im.imgInfo.exifInfo.thumbnail.isNull()))
+			{
+				ix = im.imgInfo.exifInfo.width;
+				iy = im.imgInfo.exifInfo.height;
+			}
+			else
+			{
+				ix = im.width();
+				iy = im.height();
+			}
+			int xres = im.imgInfo.xres;
+			int yres = im.imgInfo.yres;
 			QString tmp = "";
 			QString tmp2 = "";
-			if ((im.width() > w-5) || (im.height() > h-20))
+			QImage im2;
+			if ((ix > w-5) || (iy > h-44))
 			{
-				QImage im2;
 				double sx = im.width() / static_cast<double>(w-5);
-				double sy = im.height() / static_cast<double>(h-20);
+				double sy = im.height() / static_cast<double>(h-44);
 				im2 = sy < sx ?  im.smoothScale(qRound(im.width() / sx), qRound(im.height() / sx)) :
-									im.smoothScale(qRound(im.width() / sy), qRound(im.height() / sy));
-				im = im2;
-				im2.detach();
+				                 im.smoothScale(qRound(im.width() / sy), qRound(im.height() / sy));
 			}
+			else
+				im2 = im.copy();
 			QPainter p;
 			pixmap()->fill(white);
 			p.begin(pixmap());
-			p.drawImage(0, 0, im);
-			p.drawText(2, h-5, tr("Size:")+" "+tmp.setNum(ix)+" x "+tmp2.setNum(iy));
+			p.drawImage(0, 0, im2);
+			p.drawText(2, h-29, tr("Size:")+" "+tmp.setNum(ix)+" x "+tmp2.setNum(iy));
+			p.drawText(2, h-17, tr("Resolution:")+" "+tmp.setNum(xres)+" x "+tmp2.setNum(yres)+" "+ tr("DPI"));
+			QString cSpace;
+			if ((ext == "pdf") || (ext == "eps") || (ext == "ps"))
+				cSpace = tr("Unknown");
+			else
+			{
+				switch (im.imgInfo.colorspace)
+				{
+					case 0:
+						cSpace = tr("RGB");
+						break;
+					case 1:
+						cSpace = tr("CMYK");
+						break;
+					case 2:
+						cSpace = tr("Grayscale");
+						break;
+				}
+			}
+			p.drawText(2, h-5, tr("Colorspace:")+" "+cSpace);
 			p.end();
 			repaint();
 		}
 	}
 	else
 	{
-		if (loadText(name, &Buffer))
+		ScSlaInfoReader infoReader;
+		if (infoReader.readInfos(name))
 		{
-			if (Buffer.startsWith("<SCRIBUS"))
-			{
-				QDomDocument docu("scridoc");
-				if(!docu.setContent(Buffer))
-					return;
-				QDomElement elem=docu.documentElement();
-				if ((elem.tagName() != "SCRIBUS") && (elem.tagName() != "SCRIBUSUTF8"))
-					return;
-				QDomNode DOC=elem.firstChild();
-				QDomElement dc=DOC.toElement();
-				QString Tit = tr("Title:")+" ";
-				QString ti2 = dc.attribute("TITLE");
-				if (ti2 == "")
-					ti2= tr("No Title");
-				Tit += ti2+"\n";
-				QString Aut = tr("Author:")+" ";
-				QString au2 = dc.attribute("AUTHOR");
-				if (au2 == "")
-					au2 = tr("Unknown");
-				Aut += au2;
-				setText( tr("Scribus Document")+"\n\n"+Tit+Aut);
-			}
-			else  if ((ext == "txt") || (ext == "html") || (ext == "xml"))
+			QString Tit = tr("Title:")+" ";
+			QString ti2 = infoReader.title();
+			if (ti2.isEmpty())
+				ti2= tr("No Title");
+			Tit += ti2+"\n";
+			QString Aut = tr("Author:")+" ";
+			QString au2 = infoReader.author();
+			if (au2.isEmpty())
+				au2 = tr("Unknown");
+			Aut += au2+"\n";
+			QString Fmt = tr("Version:")+" ";
+			QString fm2 = infoReader.format();
+			if (fm2.isEmpty())
+				fm2 = tr("Unknown");
+			Fmt += fm2;
+			setText( tr("Scribus Document")+"\n\n"+Tit+Aut+Fmt);
+		}
+		else  if ((ext == "txt") || (ext == "html") || (ext == "xml"))
+		{
+			if (loadText(name, &Buffer))
 				setText(Buffer.left(200));
 		}
 	}
-}	
+}
 
 void FDialogPreview::previewUrl( const QUrl &url )
 {
 	if (url.isLocalFile())
-		GenPreview(url.path());
+	{
+		QFileInfo finfo(url.path());
+		if (filePath != finfo.filePath())
+		{
+			filePath = finfo.filePath();
+			GenPreview(url.path());
+		}
+	}
 }
 
-CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString filter, 
-                             bool Pre, bool mod, bool comp, bool cod, bool dirOnly)
-                             : QFileDialog(QString::null, filter, pa, 0, true)
+CustomFDialog::CustomFDialog(QWidget *parent, QString wDir, QString caption,
+							 QString filter, bool preview,
+							 bool existing, bool compress,
+							 bool codec, bool dirOnly)
+			: QFileDialog(QString::null, filter, parent, 0, true)
 {
  	setIcon(loadIcon("AppIcon.png"));
- 	setCaption(cap);
+ 	setCaption(caption);
 	cDir = QDir(wDir);
 	setDir(cDir);
 	setIconProvider(new ImIconProvider(this));
@@ -202,7 +250,7 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString fil
 		Layout1 = new QHBoxLayout(Layout);
 		Layout1->setSpacing( 0 );
 		Layout1->setMargin( 0 );
-		SaveZip = new QCheckBox(tr( "&Compress File" ), Layout, "test");
+		SaveZip = new QCheckBox( tr( "&Compress File" ), Layout, "test");
 		Layout1->addWidget(SaveZip, Qt::AlignLeft);
 		QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 		Layout1->addItem( spacer );
@@ -211,7 +259,7 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString fil
 		Layout1C = new QHBoxLayout(LayoutC);
 		Layout1C->setSpacing( 0 );
 		Layout1C->setMargin( 0 );
-		WFonts = new QCheckBox(tr( "&Include Fonts" ), LayoutC, "test");
+		WFonts = new QCheckBox( tr( "&Include Fonts" ), LayoutC, "test");
 		Layout1C->addWidget(WFonts, Qt::AlignLeft);
 		QSpacerItem* spacer2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 		Layout1C->addItem( spacer2 );
@@ -223,26 +271,26 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString fil
 		setContentsPreviewEnabled( true );
 		pw = new FDialogPreview( this );
 		setContentsPreview( pw, pw );
-		if (comp)
+		if (compress)
 		{
 			Layout = new QFrame(this);
 			Layout1 = new QHBoxLayout(Layout);
 			Layout1->setSpacing( 6 );
 			Layout1->setMargin( 0 );
-			SaveZip = new QCheckBox(tr( "&Compress File" ), Layout, "test");
+			SaveZip = new QCheckBox( tr( "&Compress File" ), Layout, "test");
 			Layout1->addWidget(SaveZip);
 			QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 			Layout1->addItem( spacer );
 		}
-		if (mod)
+		if (existing)
 			setMode(QFileDialog::ExistingFile);
 		else
 		{
 			setMode(QFileDialog::AnyFile);
-			if (comp)
+			if (compress)
 				addWidgets(0, Layout, 0);
 		}
-		if (cod)
+		if (codec)
 		{
 			LayoutC = new QFrame(this);
 			Layout1C = new QHBoxLayout(LayoutC);
@@ -250,12 +298,16 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString fil
 			Layout1C->setMargin( 4 );
 			TxCodeT = new QLabel(this);
 			TxCodeT->setText( tr("Encoding:"));
-			TxCodeM = new QComboBox(true, LayoutC, "Cod");
+			TxCodeM = new ScComboBox(true, LayoutC, "Cod");
 			TxCodeM->setEditable(false);
-			QString tmp_txc[] = {"ISO 8859-1", "ISO 8859-2", "ISO 8859-3", "ISO 8859-4", "ISO 8859-5", "ISO 8859-6",
-								"ISO 8859-7", "ISO 8859-8", "ISO 8859-9", "ISO 8859-10", "ISO 8859-13", "ISO 8859-14",
-								"ISO 8859-15", "utf8", "KOI8-R", "KOI8-U", "CP1250", "CP1251", "CP1252", "CP1253",
-								"CP1254", "CP1255", "CP1256", "CP1257", "Apple Roman"};
+			QString tmp_txc[] = {"ISO 8859-1", "ISO 8859-2", "ISO 8859-3",
+								"ISO 8859-4", "ISO 8859-5", "ISO 8859-6",
+								"ISO 8859-7", "ISO 8859-8", "ISO 8859-9",
+								"ISO 8859-10", "ISO 8859-13", "ISO 8859-14",
+								"ISO 8859-15", "utf8", "KOI8-R", "KOI8-U",
+								"CP1250", "CP1251", "CP1252", "CP1253",
+								"CP1254", "CP1255", "CP1256", "CP1257",
+								"Apple Roman"};
 			size_t array = sizeof(tmp_txc) / sizeof(*tmp_txc);
 			for (uint a = 0; a < array; ++a)
 				TxCodeM->insertItem(tmp_txc[a]);
@@ -281,22 +333,29 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString fil
 			Layout1C->addItem( spacer2 );
 			addWidgets(TxCodeT, LayoutC, 0);
 		}
-		setPreviewMode(Pre ? QFileDialog::Contents : QFileDialog::NoPreview );
+		setPreviewMode(preview ? QFileDialog::Contents : QFileDialog::NoPreview );
 		setViewMode( QFileDialog::List );
-		if (comp)
-			connect(SaveZip, SIGNAL(clicked()), this, SLOT(HandleComp()));
+		if (compress)
+			connect(SaveZip, SIGNAL(clicked()), this, SLOT(handleCompress()));
 	}
 	HomeB = new QToolButton(this);
 	HomeB->setIconSet(loadIcon("gohome.png"));
+	#ifdef _WIN32
+	HomeB->setAutoRaise(true);
+	#endif
 	HomeB->setTextLabel( tr("Moves to your Document Directory.\nThis can be set in the Preferences."));
 	connect(HomeB, SIGNAL(clicked()), this, SLOT(slotHome()));
 	addToolButton(HomeB);
+	// default init
+	extZip = "gz";
 }
 
 CustomFDialog::~CustomFDialog()
 {
 	setIconProvider(0);
-	cDir.setCurrent(dir()->path());
+	const QDir* d(dir());
+	cDir.setCurrent(d->path());
+	delete d;
 }
 
 void CustomFDialog::slotHome()
@@ -304,33 +363,47 @@ void CustomFDialog::slotHome()
 	setDir(QDir(DocDir));
 }
 
-void CustomFDialog::HandleComp()
+void CustomFDialog::handleCompress()
 {
-	QString tmp;
-	tmp = selectedFile();
+	QFileInfo tmp;
+	tmp.setFile(selectedFile());
+	QString e(tmp.extension());
+	QStringList ex = QStringList::split(".", e);
+	QString baseExt = "";
+	for (uint a = 0; a < ex.count(); a++)
+	{
+		if ((ex[a] != "sla") && (ex[a] != "SLA") && (ex[a] != "gz") && (ex[a] != "GZ"))
+			baseExt += "."+ex[a];
+	}
 	if (SaveZip->isChecked())
 	{
-		if (tmp.right(3) != ".gz")
-		{
-//			tmp = tmp + tmp.right(3) == "svg" ? "z" : ".gz";
-			if (tmp.right(3) == "svg")
-				tmp = tmp+"z";
-			else
-				tmp = tmp+".gz";
-		}
-		setSelection(tmp);
+		if (e != extZip)
+			tmp.setFile(tmp.baseName() + baseExt + "." + extZip);
 	}
 	else
 	{
-		int en = tmp.findRev(".gz");
-		if (en > 0)
-			tmp.remove(en,3);
-		else
-		{
-			en = tmp.findRev("z");
-			if (en > 0)
-				tmp.remove(en,1);
-		}
+		if (e != ext)
+			tmp.setFile(tmp.baseName() + baseExt + "." + ext);
 	}
-	setSelection(tmp);
+	setSelection(tmp.fileName());
+}
+
+void CustomFDialog::setExtension(QString e)
+{
+	ext = e;
+}
+
+QString CustomFDialog::extension()
+{
+	return ext;
+}
+
+void CustomFDialog::setZipExtension(QString e)
+{
+	extZip = e;
+}
+
+QString CustomFDialog::zipExtension()
+{
+	return extZip;
 }
