@@ -1,3 +1,9 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
                           hyphenator.cpp  -  description
                              -------------------
@@ -18,51 +24,39 @@
 #include "hyphenator.moc"
 #include "hyask.h"
 
-#ifdef _MSC_VER
- #if (_MSC_VER >=1200)
-  #include "win-config.h"
- #endif
-#else
- #include "config.h"
-#endif
+#include "scconfig.h"
 
 #include <qregexp.h>
 #include <qcursor.h>
 #include <qdir.h>
 #include <cstdlib>
 #include <string>
+#include "scpaths.h"
 #include "scribus.h"
 #include "prefsfile.h"
+#include "prefsmanager.h"
 
-extern PrefsFile* prefsFile;
-/*!
- \fn Hyphenator::Hyphenator(QWidget* parent, ScribusDoc *dok, ScribusApp* app)
- \brief Constructor reads user configuration and sets hyphenator properties.
- \date
- \author Franz Schmid
- \param parent unused
- \param dok ScribusDoc reference. It's used for preferences accessing.
- \param app ScribusApp reference. It's used for preferences accessing.
- \retval None
-*/
-Hyphenator::Hyphenator(QWidget* parent, ScribusDoc *dok, ScribusApp* app) : QObject( parent, "bu")
+
+Hyphenator::Hyphenator(QWidget* parent, ScribusDoc *dok)
+	: QObject( parent, "bu"),
+	doc(dok),
+	MinWordLen(doc->MinWordLen),
+	HyCount(doc->HyCount),
+	Automatic(doc->Automatic),
+	AutoCheck(doc->AutoCheck),
+	hdict(0),
+	useAble(false),
+	codec(0)
 {
-	char *filename = NULL;
-	doc = dok;
-	Sap = app;
-	MinWordLen = doc->MinWordLen;
-	Automatic = doc->Automatic;
-	AutoCheck = doc->AutoCheck;
-	HyCount = doc->HyCount;
- 	QString pfad = LIBDIR;
-	if (Sap->Sprachen.contains(doc->Language))
+ 	QString pfad = ScPaths::instance().dictDir();
+	if (ScMW->Sprachen.contains(doc->Language))
 		Language = doc->Language;
 	else
 	{
-		Language = Sap->Prefs.Language;
+		Language = PrefsManager::instance()->appPrefs.Language;
 		doc->Language = Language;
 	}
-	pfad += "dicts/" + Sap->Sprachen[Language];
+	pfad += ScMW->Sprachen[Language];
 	QFile f(pfad);
 	if (f.open(IO_ReadOnly))
 	{
@@ -78,44 +72,28 @@ Hyphenator::Hyphenator(QWidget* parent, ScribusDoc *dok, ScribusApp* app) : QObj
 		hdict = NULL;
 		return;
 	}
-	QCString fn = pfad.latin1();
-	filename = fn.data();
+	QCString fn = pfad.local8Bit();
+	const char * filename = fn.data();
 	hdict = hnj_hyphen_load(filename);
 	useAble = hdict == NULL ? false : true;
 }
 
-/*!
- \fn Hyphenator::~Hyphenator()
- \brief Safely cleans hyphen. 
- \date
- \author Franz Schmid
- \param None
- \retval None
- */
 Hyphenator::~Hyphenator()
 {
 	hnj_hyphen_free(hdict);
 }
 
-/*!
- \fn void Hyphenator::slotNewDict(QString name)
- \brief Loads dictionary and fills parameters like \a useAble, \a codec, \a hdict.
- \date
- \author Franz Schmid
- \param name is the name of specified language - filename.
- \retval None
- */
 void Hyphenator::slotNewDict(QString name)
 {
-	if (!Sap->Sprachen.contains(name))
+	if (!ScMW->Sprachen.contains(name))
 		return;
 	char *filename = NULL;
 	if (hdict != NULL)
 		hnj_hyphen_free(hdict);
- 	QString pfad = LIBDIR;
+ 	QString pfad = ScPaths::instance().dictDir();
 	Language = name;
 	doc->Language = name;
-	pfad += "dicts/" + Sap->Sprachen[Language];
+	pfad += ScMW->Sprachen[Language];
 	QFile f(pfad);
 	if (f.open(IO_ReadOnly))
 	{
@@ -131,22 +109,12 @@ void Hyphenator::slotNewDict(QString name)
 		hdict = NULL;
 		return;
 	}
-	QCString fn = pfad.latin1();
+	QCString fn = pfad.local8Bit();
 	filename = fn.data();
 	hdict = hnj_hyphen_load(filename);
 	useAble = hdict == NULL ? false : true;
 }
 
-/*!
- \fn void Hyphenator::slotNewSettings(int Wordlen, bool Autom, bool ACheck)
- \brief Writes actual hyphen configuration into \a doc object.
- \date
- \author Franz Schmid
- \param WordLen lenght of the word.
- \param Autom is automatic flag.
- \param ACheck AutoCheck flag.
- \retval None
- */
 void Hyphenator::slotNewSettings(int Wordlen, bool Autom, bool ACheck, int Num)
 {
 	MinWordLen = Wordlen;
@@ -159,26 +127,16 @@ void Hyphenator::slotNewSettings(int Wordlen, bool Autom, bool ACheck, int Num)
 	doc->HyCount = Num;
 }
 
-/*! 
- \fn void Hyphenator::slotHyphenateWord(PageItem* it, QString text, int firstC)
- \brief Make hyphenation when user edits text in text frame manually.
- \detail If is everything set correctly and textframe selected language fits the
-    dictionary language. At first removes any old hyphens then sets new one.
- \param it references \see PageItem - text frame.
- \param text is a word to hyphenate.
- \param firstC is the first character of the word in \a it item.
- \retval None
- */
 void Hyphenator::slotHyphenateWord(PageItem* it, QString text, int firstC)
 {
-	if ((!useAble) || (!Sap->Sprachen.contains(it->Language)))
+	if ((!useAble) || (!ScMW->Sprachen.contains(it->Language)))
 		return;
 	const char *word;
 	char *buffer;
 	const int BORDER = 2;
 	QCString te;
 
-	uint maxC = it->Ptext.count() - 1;
+	uint maxC = it->itemText.count() - 1;
 	QString found = text;
 	if (static_cast<int>(found.length()) > MinWordLen-1)
 	{
@@ -192,47 +150,39 @@ void Hyphenator::slotHyphenateWord(PageItem* it, QString text, int firstC)
 			uint i = 0;
 		  	buffer[strlen(word)] = '\0';
 			for (i = 1; i < found.length()-1; ++i)
-				it->Ptext.at(QMIN(maxC, i+firstC))->cstyle &= 127;		// Delete any old Hyphens
+				it->itemText.at(QMIN(maxC, i+firstC))->cstyle &= 1919;		// Delete any old Hyphens
 			for (i = 1; i < found.length()-1; ++i)
 			{
 				if(buffer[i] & 1)
-					it->Ptext.at(QMIN(maxC, i+firstC))->cstyle |= 128;	// Set new Hyphens according Buffer
+					it->itemText.at(QMIN(maxC, i+firstC))->cstyle |= 128;	// Set new Hyphens according Buffer
 			}
 		}
 		free(buffer);
 	}
 }
 
-/*! 
- \fn void Hyphenator::slotHyphenate(PageItem* it)
- \brief Make hyphenation as described in \see slotHyphenateWord for the whole text frame.
- \date
- \author Franz Schmid
- \param it references \see PageItem - text frame.
- \retval None
- */
 void Hyphenator::slotHyphenate(PageItem* it)
 {
-	PageItem *nb = it;
+	PageItem *nextItem = it;
 	PageItem *nb1;
-	while (nb != 0)
+	while (nextItem != 0)
 	{
-		if (nb->BackBox != 0)
-			nb = nb->BackBox;
+		if (nextItem->BackBox != 0)
+			nextItem = nextItem->BackBox;
 		else
 			break;
 	}
-	nb1 = nb;
-	while (nb != 0)
+	nb1 = nextItem;
+	while (nextItem != 0)
 	{
-		uint a = nb->Ptext.count();
+		uint a = nextItem->itemText.count();
 		for (uint s = 0; s < a; ++s)
-			nb1->Ptext.append(nb->Ptext.take(0));
-		nb->MaxChars = 0;
-		nb->CPos = 0;
-		nb = nb->NextBox;
+			nb1->itemText.append(nextItem->itemText.take(0));
+		nextItem->MaxChars = 0;
+		nextItem->CPos = 0;
+		nextItem = nextItem->NextBox;
 	}
-	if ((!useAble) || (nb1->PType != 4) || (nb1 ->Ptext.count() == 0))
+	if ((!useAble) || !(nb1->asTextFrame()) || (nb1 ->itemText.count() == 0))
 		return;
 	doc->DoDrawing = false;
 	const char *word;
@@ -241,22 +191,22 @@ void Hyphenator::slotHyphenate(PageItem* it)
 	QString text = "";
 	QString buf;
 	QCString te;
-	for (uint a = 0; a < nb1->Ptext.count(); ++a)
+	for (uint a = 0; a < nb1->itemText.count(); ++a)
 	{
 		if (nb1->HasSel)
 		{
-			if (nb1->Ptext.at(a)->cselect)
-				text += nb1->Ptext.at(a)->ch;
+			if (nb1->itemText.at(a)->cselect)
+				text += nb1->itemText.at(a)->ch;
 		}
 		else
-			text += nb1->Ptext.at(a)->ch;
+			text += nb1->itemText.at(a)->ch;
 	}
 	int firstC = 0;
 	if (nb1->HasSel)
 	{
-		for (uint a = 0; a < nb1->Ptext.count(); ++a)
+		for (uint a = 0; a < nb1->itemText.count(); ++a)
 		{
-			if (nb1->Ptext.at(a)->cselect)
+			if (nb1->itemText.at(a)->cselect)
 			{
 				firstC = static_cast<int>(a);
 				break;
@@ -267,9 +217,10 @@ void Hyphenator::slotHyphenate(PageItem* it)
 	int Ccount = 0;
 	QString found = "";
 	QString found2 = "";
-	uint maxC = nb1->Ptext.count() - 1;
+	uint maxC = nb1->itemText.count() - 1;
 	qApp->setOverrideCursor(QCursor(waitCursor), true);
-	while ((firstC+Ccount < static_cast<int>(text.length())) && (firstC != -1) && (lastC < static_cast<int>(text.length())))
+	while ((firstC+Ccount < static_cast<int>(text.length())) && (firstC != -1) && 
+			(lastC < static_cast<int>(text.length())))
 	{
 		firstC = text.find(QRegExp("\\w"), firstC+Ccount);
 		if (firstC < 0)
@@ -292,7 +243,7 @@ void Hyphenator::slotHyphenate(PageItem* it)
 	  			uint i = 0;
   				buffer[strlen(word)] = '\0';
 				for (i = 1; i < found.length()-1; ++i)
-					nb1->Ptext.at(QMIN(maxC, i+firstC))->cstyle &= 127;		// Delete any old Hyphens
+					nb1->itemText.at(QMIN(maxC, i+firstC))->cstyle &= 1919;		// Delete any old Hyphens
 				bool hasHyphen = false;
 				for (i = 1; i < found.length()-1; ++i)
 				{
@@ -316,7 +267,7 @@ void Hyphenator::slotHyphenate(PageItem* it)
 						}
 						outs += found2.right(1);
 						qApp->setOverrideCursor(QCursor(ArrowCursor), true);
-						PrefsContext* prefs = prefsFile->getContext("hyhpen_options");
+						PrefsContext* prefs = PrefsManager::instance()->prefsFile->getContext("hyhpen_options");
 						int xpos = prefs->getInt("Xposition", -9999);
 						int ypos = prefs->getInt("Yposition", -9999);
 						HyAsk *dia = new HyAsk((QWidget*)parent(), outs);
@@ -331,7 +282,7 @@ void Hyphenator::slotHyphenate(PageItem* it)
 							{
 								QChar cht = outs[i];
 								if (cht == "-")
-									nb1->Ptext.at(QMIN(maxC, ii+firstC))->cstyle |= 128;
+									nb1->itemText.at(QMIN(maxC, ii+firstC))->cstyle |= 128;
 								else
 									ii++;
 							}
@@ -354,7 +305,7 @@ void Hyphenator::slotHyphenate(PageItem* it)
 						for (i = 1; i < found.length()-1; ++i)
 						{
 							if(buffer[i] & 1)
-								nb1->Ptext.at(QMIN(maxC, i+firstC))->cstyle |= 128;
+								nb1->itemText.at(QMIN(maxC, i+firstC))->cstyle |= 128;
 						}
 	  				}
 				}
@@ -367,5 +318,42 @@ void Hyphenator::slotHyphenate(PageItem* it)
 	}
 	qApp->setOverrideCursor(QCursor(ArrowCursor), true);
 	doc->DoDrawing = true;
-	nb1->OwnPage->RefreshItem(nb1);
+}
+
+void Hyphenator::slotDeHyphenate(PageItem* it)
+{
+	PageItem *nextItem = it;
+	PageItem *nb1;
+	if (!(it->asTextFrame()) || (it ->itemText.count() == 0))
+		return;
+	while (nextItem != 0)
+	{
+		if (nextItem->BackBox != 0)
+			nextItem = nextItem->BackBox;
+		else
+			break;
+	}
+	nb1 = nextItem;
+	while (nextItem != 0)
+	{
+		uint a = nextItem->itemText.count();
+		for (uint s = 0; s < a; ++s)
+			nb1->itemText.append(nextItem->itemText.take(0));
+		nextItem->MaxChars = 0;
+		nextItem->CPos = 0;
+		nextItem = nextItem->NextBox;
+	}
+	doc->DoDrawing = false;
+	for (uint a = 0; a < nb1->itemText.count(); ++a)
+	{
+		if (nb1->HasSel)
+		{
+			if (nb1->itemText.at(a)->cselect)
+				nb1->itemText.at(a)->cstyle &= 1919;
+		}
+		else
+			nb1->itemText.at(a)->cstyle &= 1919;
+	}
+	qApp->setOverrideCursor(QCursor(ArrowCursor), true);
+	doc->DoDrawing = true;
 }
