@@ -40,6 +40,7 @@ MSpinBox::MSpinBox(QWidget *pa, int s):QSpinBox(pa)
 	oldLineStep=0;
 	readOnly=false;
 	edited = false;
+	tabAdvance=true;
     connect( ed, SIGNAL(textChanged(const QString&)), SLOT(textChanged()) );
 }
 
@@ -54,6 +55,7 @@ MSpinBox::MSpinBox(double minValue, double maxValue, QWidget *pa, int s):QSpinBo
 	setMaxValue(maxValue);
 	readOnly=false;
 	edited = false;
+	tabAdvance=true;
     connect( ed, SIGNAL(textChanged(const QString&)), SLOT(textChanged()) );
 }
 
@@ -62,7 +64,7 @@ void MSpinBox::setParameters( int s )
 	if (s>=0 && s <=unitGetMaxIndex())
 	{
 		Width=s;
-		Decimals=static_cast<int>(pow(10, s));
+		Decimals=static_cast<int>(pow(10.0, s));
 	}
 	else
 	{
@@ -72,6 +74,11 @@ void MSpinBox::setParameters( int s )
 	edited = false;
 }
 
+void MSpinBox::setTabAdvance(bool enable)
+{
+	tabAdvance = enable;
+}
+
 bool MSpinBox::eventFilter( QObject* ob, QEvent* ev )
 {
 	bool retval = false;
@@ -101,6 +108,14 @@ bool MSpinBox::eventFilter( QObject* ob, QEvent* ev )
 			qApp->sendEvent( this, ev );
 			return retval;
 		}
+		else if ((k->key() == Key_Return) || (k->key() == Key_Enter) || (k->key() == Key_Tab))
+		{
+			if (!tabAdvance)
+			{
+				QSpinBox::interpretText();
+				return true;
+			}
+		}
 	}
 	if (ev->type() == QEvent::KeyRelease )
 	{
