@@ -594,6 +594,8 @@ void PageItem_TextFrame::DrawObj_Item(ScPainter *p, QRect e, double sc)
 					absa = hl->cab;
 					if (m_Doc->docParagraphStyles[absa].LineSpaMode == 1)
 						m_Doc->docParagraphStyles[absa].LineSpa = RealFHeight(m_Doc, hl->cfont, hl->csize);
+					else if (m_Doc->docParagraphStyles[absa].LineSpaMode == 2)
+						m_Doc->docParagraphStyles[absa].LineSpa = m_Doc->typographicSettings.valueBaseGrid;
 					if (a == 0)
 					{
 						if (BackBox != 0)
@@ -1511,7 +1513,7 @@ void PageItem_TextFrame::DrawObj_Item(ScPainter *p, QRect e, double sc)
 						tabDist = ColBound.x();
 						uint tabCc = 0;
 						uint loopC = BuPos3;
-						if (m_Doc->guidesSettings.showControls)
+						if (m_Doc->guidesSettings.showControls && (startLin+loopC+1 < (uint) itemText.length()))
 							loopC++;
 						for (uint zc = 0; zc<loopC; ++zc)
 						{
