@@ -1,18 +1,15 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 #ifndef EXPORTFORM_H
 #define EXPORTFORM_H
 
 #include <qvariant.h>
 #include <qdialog.h>
 #include <qradiobutton.h>
-#include <prefscontext.h>
 
 class QVBoxLayout;
 class QHBoxLayout;
@@ -24,6 +21,8 @@ class QLabel;
 class QLineEdit;
 class QPushButton;
 class QSpinBox;
+class PrefsContext;
+class MSpinBox;
 
 class ExportForm : public QDialog
 {
@@ -46,7 +45,7 @@ public:
     QComboBox* BitmapType;
     QSpinBox* QualityBox;
     QSpinBox* DPIBox;
-	QSpinBox* EnlargementBox;
+	MSpinBox* EnlargementBox;
     QButtonGroup* ButtonGroup1;
     QRadioButton* OnePageRadio;
     QRadioButton* AllPagesRadio;
