@@ -109,7 +109,8 @@ EPSPlug::EPSPlug(QString fName, int flags, bool showProgress)
 					FarNam = FarNam.remove(FarNam.length()-1,1);
 					QRegExp badchars("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%]");
 					FarNam = FarNam.simplifyWhiteSpace().replace( badchars, "_" );
-					cc = ScColor(static_cast<int>(255 * c), static_cast<int>(255 * m), static_cast<int>(255 * y), static_cast<int>(255 * k));
+					cc = ScColor(qRound(255 * c), qRound(255 * m), qRound(255 * y), qRound(255 * k));
+				//	cc = ScColor(static_cast<int>(255 * c), static_cast<int>(255 * m), static_cast<int>(255 * y), static_cast<int>(255 * k));
 					cc.setSpotColor(true);
 					CustColors.insert(FarNam, cc);
 					while (!ts.atEnd())
@@ -126,7 +127,8 @@ EPSPlug::EPSPlug(QString fName, int flags, bool showProgress)
 						FarNam = FarNam.remove(FarNam.length()-1,1);
 						QRegExp badchars("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%]");
 						FarNam = FarNam.simplifyWhiteSpace().replace( badchars, "_" );
-						cc = ScColor(static_cast<int>(255 * c), static_cast<int>(255 * m), static_cast<int>(255 * y), static_cast<int>(255 * k));
+						cc = ScColor(qRound(255 * c), qRound(255 * m), qRound(255 * y), qRound(255 * k));
+					//	cc = ScColor(static_cast<int>(255 * c), static_cast<int>(255 * m), static_cast<int>(255 * y), static_cast<int>(255 * k));
 						cc.setSpotColor(true);
 						CustColors.insert(FarNam, cc);
 					}
@@ -331,8 +333,8 @@ bool EPSPlug::convert(QString fn, double x, double y, double b, double h)
 	args.append( "closefile" );
 	args.append( "quit" );
 	QCString finalCmd = args.join(" ").local8Bit();
-	int ret = System(args, errFile, errFile);
-	if (ret != 0)
+	int ret = System(args, errFile, errFile, &cancel);
+	if (ret != 0 && !cancel)
 	{
 		qDebug("PostScript import failed when calling gs as: \n%s\n", finalCmd.data());
 		qDebug("Ghostscript diagnostics:\n");
@@ -353,7 +355,7 @@ bool EPSPlug::convert(QString fn, double x, double y, double b, double h)
 		QMessageBox::critical(0, tr("Fatal Error"), mess, 1, 0, 0);
 		return false;
 	}
-	if(progressDialog) {
+	if(progressDialog && !cancel) {
 		progressDialog->setOverallProgress(2);
 		progressDialog->setLabel("GI", tr("Generating Items"));
 		ScQApp->processEvents();
@@ -766,9 +768,12 @@ QString EPSPlug::parseColor(QString vals, colorModel model)
 		Code >> g;
 		Code >> b;
 		Code >> Opacity;
-		int Rc = static_cast<int>(r * 255 + 0.5);
+	/*	int Rc = static_cast<int>(r * 255 + 0.5);
 		int Gc = static_cast<int>(g * 255 + 0.5);
-		int Bc = static_cast<int>(b * 255 + 0.5);
+		int Bc = static_cast<int>(b * 255 + 0.5); */
+		int Rc = qRound(r * 255);
+		int Gc = qRound(g * 255);
+		int Bc = qRound(b * 255);
 		int hR, hG, hB;
 		tmp.setColorRGB(Rc, Gc, Bc);
 		for (it = Doku->PageColors.begin(); it != Doku->PageColors.end(); ++it)
@@ -776,10 +781,11 @@ QString EPSPlug::parseColor(QString vals, colorModel model)
 			Doku->PageColors[it.key()].getRGB(&hR, &hG, &hB);
 			if ((Rc == hR) && (Gc == hG) && (Bc == hB))
 			{
-				if (Doku->PageColors[it.key()].getColorModel() == colorModelRGB)
+				if (it.data().getColorModel() == colorModelRGB)
 				{
 					ret = it.key();
 					found = true;
+					break;
 				}
 			}
 		}
@@ -791,10 +797,14 @@ QString EPSPlug::parseColor(QString vals, colorModel model)
 		Code >> y;
 		Code >> k;
 		Code >> Opacity;
-		int Cc = static_cast<int>(c * 255 + 0.5);
+	/*	int Cc = static_cast<int>(c * 255 + 0.5);
 		int Mc = static_cast<int>(m * 255 + 0.5);
 		int Yc = static_cast<int>(y * 255 + 0.5);
-		int Kc = static_cast<int>(k * 255 + 0.5);
+		int Kc = static_cast<int>(k * 255 + 0.5); */
+		int Cc = qRound(c * 255);
+		int Mc = qRound(m * 255);
+		int Yc = qRound(y * 255);
+		int Kc = qRound(k * 255);
 		int hC, hM, hY, hK;
 		tmp.setColor(Cc, Mc, Yc, Kc);
 		for (it = Doku->PageColors.begin(); it != Doku->PageColors.end(); ++it)
@@ -802,10 +812,11 @@ QString EPSPlug::parseColor(QString vals, colorModel model)
 			Doku->PageColors[it.key()].getCMYK(&hC, &hM, &hY, &hK);
 			if ((Cc == hC) && (Mc == hM) && (Yc == hY) && (Kc == hK))
 			{
-				if (Doku->PageColors[it.key()].getColorModel() == colorModelCMYK)
+				if (it.data().getColorModel() == colorModelCMYK)
 				{
 					ret = it.key();
 					found = true;
+					break;
 				}
 			}
 		}
