@@ -1,24 +1,23 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
- *   Riku Leino, riku.leino@gmail.com                                          *
+ *   Riku Leino, tsoots@gmail.com                                          *
  ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
- #include "satdialog.h"
+#include "satdialog.h"
 #include "satdialog.moc"
+#include "scribusapi.h"
+#include "prefsmanager.h"
 #include <prefsfile.h>
 
-extern QPixmap loadIcon(QString nam);
-extern PrefsFile* prefsFile;
+extern QPixmap SCRIBUS_API loadIcon(QString nam);
 
-satdialog::satdialog(QWidget* parent, QString tmplName, int pageW, int pageH) : QDialog(parent, "satdialog", TRUE)
+satdialog::satdialog(QWidget* parent, QString tmplName, int pageW, int pageH) : QDialog(parent, "satdialog", true)
 {
-	setCaption(tr("Save as Template"));
+	setCaption( tr("Save as Template"));
 	setIcon(loadIcon("AppIcon.png"));
 	readPrefs();
 	
@@ -123,7 +122,7 @@ void satdialog::detailClicked()
 
 void satdialog::fullDetail() 
 {
-	detailButton->setText(tr("Less Details"));
+	detailButton->setText( tr("Less Details"));
 	psizeLabel->setHidden(false);
 	psizeLabel->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred));
 	catsLabel->setHidden(false);
@@ -159,7 +158,7 @@ void satdialog::fullDetail()
 
 void satdialog::minimumDetail()
 {
-	detailButton->setText(tr("More Details"));
+	detailButton->setText( tr("More Details"));
 	catsLabel->hide();
 	catsLabel->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
 	psizeLabel->hide();
@@ -197,7 +196,7 @@ void satdialog::minimumDetail()
 
 void satdialog::readPrefs() 
 {
-	prefs = prefsFile->getPluginContext("satemplate");
+	prefs = PrefsManager::instance()->prefsFile->getPluginContext("satemplate");
 	author = prefs->get("author", "");
 	email = prefs->get("email", "");
 	isFullDetail = prefs->getBool("isFullDetail", false);
@@ -214,59 +213,36 @@ void satdialog::setupCategories()
 {
 	// en will be used in template.xml and it will be then replaced with the lang when used for users
 	// to get the categories in their language.
-	QString* en = new QString("Newsletters"); QString* lang = new QString(QObject::tr("Newsletters"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Brochures"); lang = new QString(QObject::tr("Brochures"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Catalogs"); lang = new QString(QObject::tr("Catalogs"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Flyers"); lang = new QString(QObject::tr("Flyers"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Signs"); lang = new QString(QObject::tr("Signs"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Cards"); lang = new QString(QObject::tr("Cards"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Letterheads"); lang = new QString(QObject::tr("Letterheads"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Envelopes"); lang = new QString(QObject::tr("Envelopes"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Business Cards"); lang = new QString(QObject::tr("Business Cards"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Calendars"); lang = new QString(QObject::tr("Calendars"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Advertisements"); lang = new QString(QObject::tr("Advertisements"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Labels"); lang = new QString(QObject::tr("Labels"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Menus"); lang = new QString(QObject::tr("Menus"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Programs"); lang = new QString(QObject::tr("Programs"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("PDF Forms"); lang = new QString(QObject::tr("PDF Forms"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("PDF Presentations"); lang = new QString(QObject::tr("PDF Presentations"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Magazines"); lang = new QString(QObject::tr("Magazines"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Posters"); lang = new QString(QObject::tr("Posters"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Announcements"); lang = new QString(QObject::tr("Announcements"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Text Documents"); lang = new QString(QObject::tr("Text Documents"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Folds"); lang = new QString(QObject::tr("Folds"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Media Cases"); lang = new QString(QObject::tr("Media Cases"));
-	cats.push_back(new Pair(en,lang));
-	en = new QString("Own Templates"); lang = new QString(QObject::tr("Own Templates"));
-	cats.push_back(new Pair(en,lang));
+	cats.insert(QString("Newsletters"), QObject::tr("Newsletters"));
+	cats.insert(QString("Brochures")  , QObject::tr("Brochures"));
+	cats.insert(QString("Catalogs")   , QObject::tr("Catalogs"));
+	cats.insert(QString("Flyers")     , QObject::tr("Flyers"));
+	cats.insert(QString("Signs")      , QObject::tr("Signs"));
+	cats.insert(QString("Cards")      , QObject::tr("Cards"));
+	cats.insert(QString("Letterheads"), QObject::tr("Letterheads"));
+	cats.insert(QString("Envelopes")  , QObject::tr("Envelopes"));
+	cats.insert(QString("Business Cards"), QObject::tr("Business Cards"));
+	cats.insert(QString("Calendars")  , QObject::tr("Calendars"));
+	cats.insert(QString("Advertisements"), QObject::tr("Advertisements"));
+	cats.insert(QString("Labels")     , QObject::tr("Labels"));
+	cats.insert(QString("Menus")      , QObject::tr("Menus"));
+	cats.insert(QString("Programs")   , QObject::tr("Programs"));
+	cats.insert(QString("PDF Forms")  , QObject::tr("PDF Forms"));
+	cats.insert(QString("PDF Presentations") , QObject::tr("PDF Presentations"));
+	cats.insert(QString("Magazines")  , QObject::tr("Magazines"));
+	cats.insert(QString("Posters")    , QObject::tr("Posters"));
+	cats.insert(QString("Announcements") , QObject::tr("Announcements"));
+	cats.insert(QString("Text Documents"), QObject::tr("Text Documents"));
+	cats.insert(QString("Folds")        , QObject::tr("Folds"));
+	cats.insert(QString("Media Cases")  , QObject::tr("Media Cases"));
+	cats.insert(QString("Own Templates"), QObject::tr("Own Templates"));
 	
-	QStringList* list = new QStringList();
-	for (uint i = 0; i < cats.size(); ++i)
-		list->append(*cats[i]->second);
-	list->sort();
-	QStringList list2 = *list;
-	catsCombo->insertStringList(list2);
+	QStringList list;
+	QMap<QString, QString>::ConstIterator it;
+	for (it = cats.constBegin(); it != cats.constEnd(); ++it)
+		list.append(it.data());
+	list.sort();
+	catsCombo->insertStringList(list);
 	catsCombo->insertItem("",0);
 	catsCombo->setEditable(true);
 }
@@ -289,12 +265,12 @@ void satdialog::setupPageSize(int w, int h)
 	QString hString = QString("%1").arg(h);
 	if (w > h)
 	{
-		orient = ", "+tr("landscape");
+		orient = ", "+ tr("landscape");
 		search = hString+"x"+wString;
 	}
 	else if (w < h)
 	{
-		orient = ", "+tr("portrait");
+		orient = ", "+ tr("portrait");
 		search = wString+"x"+hString;
 	}
 	int index = -1;
@@ -320,7 +296,4 @@ void satdialog::setupPageSize(int w, int h)
 satdialog::~satdialog()
 {
 	writePrefs();
-	for(uint i = 0; i < cats.size(); ++i)
-		delete cats[i];
-
 }
