@@ -155,7 +155,7 @@ public:
 	QString GetLang(QString inLang);
 	bool getPDFDriver(const QString & fn, const QString & nam,
 					  int Components, const std::vector<int> & pageNs,
-					  const QMap<int,QPixmap> & thumbs);
+					  const QMap<int,QPixmap> & thumbs, bool* cancelled = NULL);
 	bool DoSaveAsEps(QString fn);
 	QString CFileDialog(QString wDir = ".", QString caption = "", QString filter = "", QString defNa = "",
 						bool Pre = false, bool mod = true, bool comp = false, bool cod = false,
