@@ -1,15 +1,14 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 #include "search.h"
 #include "search.moc"
 
 #include <qvariant.h>
+#include <qregexp.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qgroupbox.h>
@@ -20,34 +19,38 @@
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include <qmessagebox.h>
-#include "mspinbox.h"
+
+#include "colorm.h"
+#include "commonstrings.h"
+#include "colorcombo.h"
 #include "fontcombo.h"
+#include "mspinbox.h"
 #include "page.h"
-#include "prefsfile.h"
 #include "prefscontext.h"
-#include "styleselect.h"
+#include "prefsfile.h"
+#include "prefsmanager.h"
+#include "scribus.h"
 #include "shadebutton.h"
 #include "story.h"
-#include "scribus.h"
-extern ScribusApp* ScApp;
+#include "styleselect.h"
+#include "util.h"
+
+
 extern QPixmap loadIcon(QString nam);
-extern PrefsFile* prefsFile;
 
-
-SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, PageItem* ite, bool mode )
-							: QDialog( parent, "SearchReplace", true, 0 )
+SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* ite, bool mode )
+	: QDialog( parent, "SearchReplace", true, 0 ),
+	matchesFound(0)
 {
 	setCaption( tr( "Search/Replace" ) );
 	setIcon(loadIcon("AppIcon.png"));
-	QPixmap pm;
-	pm = QPixmap(30, 15);
-	CListe::Iterator it;
+	ColorList::Iterator it;
 	Item = ite;
 	Doc = doc;
 	NotFound = false;
 	SMode = mode;
-	SearchReplaceLayout = new QVBoxLayout( this, 10, 5, "SearchReplaceLayout"); 
-	SelLayout = new QHBoxLayout( 0, 0, 6, "SelLayout"); 
+	SearchReplaceLayout = new QVBoxLayout( this, 10, 5, "SearchReplaceLayout");
+	SelLayout = new QHBoxLayout( 0, 0, 6, "SelLayout");
 	Search = new QGroupBox( this, "Search" );
 	Search->setTitle( tr( "Search for:" ) );
 	Search->setColumnLayout(0, Qt::Vertical );
@@ -91,24 +94,24 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	size_t ar_sty = sizeof(tmp_sty) / sizeof(*tmp_sty);
 	for (uint a = 0; a < ar_sty; ++a)
 		SStyleVal->insertItem(tmp_sty[a]);
-	if (doc->Vorlagen.count() > 5)
+	if (doc->docParagraphStyles.count() > 5)
 	{
-		for (uint x = 5; x < doc->Vorlagen.count(); ++x)
-			SStyleVal->insertItem(doc->Vorlagen[x].Vname);
+		for (uint x = 5; x < doc->docParagraphStyles.count(); ++x)
+			SStyleVal->insertItem(doc->docParagraphStyles[x].Vname);
 	}
 	SStyleVal->listBox()->setMinimumWidth(SStyleVal->listBox()->maxItemWidth()+24);
-	SStyleVal->setCurrentItem(doc->CurrentABStil);
+	SStyleVal->setCurrentItem(doc->currentParaStyle);
 	SStyleVal->setEnabled(false);
 	SearchLayout->addWidget( SStyleVal, 1, 1 );
-	SFontVal = new FontCombo(Search, Prefs);
+	SFontVal = new FontCombo(Search);
 	SFontVal->setMaximumSize(190, 30);
 	SFontVal->setCurrentText(doc->CurrFont);
 	SFontVal->setEnabled(false);
 	SearchLayout->addWidget( SFontVal, 2, 1 );
 	SSizeVal = new MSpinBox( Search, 1 );
 	SSizeVal->setSuffix( tr( " pt" ) );
-	SSizeVal->setMinValue( 1 );
-	SSizeVal->setMaxValue( 1024 );
+	SSizeVal->setMinValue( 0.5 );
+	SSizeVal->setMaxValue( 2048 );
 	SSizeVal->setValue( doc->CurrFontSize / 10.0 );
 	SSizeVal->setEnabled(false);
 	SearchLayout->addWidget( SSizeVal, 3, 1 );
@@ -116,13 +119,12 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	SEffVal->setStyle(0);
 	SEffVal->setEnabled(false);
 	SearchLayout->addWidget( SEffVal, 4, 1, Qt::AlignLeft );
-	SFillVal = new QComboBox( true, Search, "SFillVal" );
+	SFillVal = new ColorCombo( true, Search, "SFillVal" );
 	SFillVal->setEditable(false);
-	SFillVal->insertItem( tr("None"));
+	SFillVal->insertItem(CommonStrings::NoneColor);
 	for (it = doc->PageColors.begin(); it != doc->PageColors.end(); ++it)
 	{
-		pm.fill(doc->PageColors[it.key()].getRGBColor());
-		SFillVal->insertItem(pm, it.key());
+		SFillVal->insertWideItem( doc->PageColors[it.key()], it.key() );
 	}
 	SFillVal->listBox()->setMinimumWidth(SFillVal->listBox()->maxItemWidth()+24);
 	SFillVal->setCurrentText(doc->CurrTextFill);
@@ -131,13 +133,12 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	SFillSVal = new ShadeButton(Search);
 	SFillSVal->setEnabled(false);
 	SearchLayout->addWidget( SFillSVal, 6, 1, Qt::AlignLeft );
-	SStrokeVal = new QComboBox( true, Search, "SStrokeVal" );
+	SStrokeVal = new ColorCombo( true, Search, "SStrokeVal" );
 	SStrokeVal->setEditable(false);
-	SStrokeVal->insertItem( tr("None"));
+	SStrokeVal->insertItem(CommonStrings::NoneColor);
 	for (it = doc->PageColors.begin(); it != doc->PageColors.end(); ++it)
 	{
-		pm.fill(doc->PageColors[it.key()].getRGBColor());
-		SStrokeVal->insertItem(pm, it.key());
+		SStrokeVal->insertWideItem( doc->PageColors[it.key()], it.key() );
 	}
 	SStrokeVal->listBox()->setMinimumWidth(SStrokeVal->listBox()->maxItemWidth()+24);
 	SStrokeVal->setCurrentText(doc->CurrTextStroke);
@@ -189,24 +190,24 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	RStyleVal->setEditable(false);
 	for (uint a = 0; a < ar_sty; ++a)
 		RStyleVal->insertItem(tmp_sty[a]);
-	if (doc->Vorlagen.count() > 5)
+	if (doc->docParagraphStyles.count() > 5)
 	{
-		for (uint x = 5; x < doc->Vorlagen.count(); ++x)
-			RStyleVal->insertItem(doc->Vorlagen[x].Vname);
+		for (uint x = 5; x < doc->docParagraphStyles.count(); ++x)
+			RStyleVal->insertItem(doc->docParagraphStyles[x].Vname);
 	}
 	RStyleVal->listBox()->setMinimumWidth(RStyleVal->listBox()->maxItemWidth()+24);
-	RStyleVal->setCurrentItem(doc->CurrentABStil);
+	RStyleVal->setCurrentItem(doc->currentParaStyle);
 	RStyleVal->setEnabled(false);
 	ReplaceLayout->addWidget( RStyleVal, 1, 1 );
-	RFontVal = new FontCombo(Replace, Prefs);
+	RFontVal = new FontCombo(Replace);
 	RFontVal->setMaximumSize(190, 30);
 	RFontVal->setCurrentText(doc->CurrFont);
 	RFontVal->setEnabled(false);
 	ReplaceLayout->addWidget( RFontVal, 2, 1 );
 	RSizeVal = new MSpinBox( Replace, 1 );
 	RSizeVal->setSuffix( tr( " pt" ) );
-	RSizeVal->setMinValue( 1 );
-	RSizeVal->setMaxValue( 1024 );
+	RSizeVal->setMinValue( 0.5 );
+	RSizeVal->setMaxValue( 2048 );
 	RSizeVal->setValue( doc->CurrFontSize / 10.0 );
 	RSizeVal->setEnabled(false);
 	ReplaceLayout->addWidget( RSizeVal, 3, 1 );
@@ -214,13 +215,12 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	REffVal->setStyle(0);
 	REffVal->setEnabled(false);
 	ReplaceLayout->addWidget( REffVal, 4, 1, Qt::AlignLeft );
-	RFillVal = new QComboBox( true, Replace, "RFillVal" );
+	RFillVal = new ColorCombo( true, Replace, "RFillVal" );
 	RFillVal->setEditable(false);
-	RFillVal->insertItem( tr("None"));
+	RFillVal->insertItem(CommonStrings::NoneColor);
 	for (it = doc->PageColors.begin(); it != doc->PageColors.end(); ++it)
 	{
-		pm.fill(doc->PageColors[it.key()].getRGBColor());
-		RFillVal->insertItem(pm, it.key());
+		RFillVal->insertWideItem( doc->PageColors[it.key()], it.key() );
 	}
 	RFillVal->listBox()->setMinimumWidth(RFillVal->listBox()->maxItemWidth()+24);
 	RFillVal->setCurrentText(doc->CurrTextFill);
@@ -229,13 +229,12 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	RFillSVal = new ShadeButton(Replace);
 	RFillSVal->setEnabled(false);
 	ReplaceLayout->addWidget( RFillSVal, 6, 1, Qt::AlignLeft );
-	RStrokeVal = new QComboBox( true, Replace, "RStrokeVal" );
+	RStrokeVal = new ColorCombo( true, Replace, "RStrokeVal" );
 	RStrokeVal->setEditable(false);
-	RStrokeVal->insertItem( tr("None"));
+	RStrokeVal->insertItem(CommonStrings::NoneColor);
 	for (it = doc->PageColors.begin(); it != doc->PageColors.end(); ++it)
 	{
-		pm.fill(doc->PageColors[it.key()].getRGBColor());
-		RStrokeVal->insertItem(pm, it.key());
+		RStrokeVal->insertWideItem( doc->PageColors[it.key()], it.key() );
 	}
 	RStrokeVal->listBox()->setMinimumWidth(RStrokeVal->listBox()->maxItemWidth()+24);
 	RStrokeVal->setCurrentText(doc->CurrTextStroke);
@@ -247,7 +246,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	SelLayout->addWidget( Replace );
 	SearchReplaceLayout->addLayout( SelLayout );
 
-	OptsLayout = new QHBoxLayout( 0, 0, 6, "OptsLayout"); 
+	OptsLayout = new QHBoxLayout( 0, 0, 6, "OptsLayout");
 	Word = new QCheckBox( tr( "&Whole Word" ), this, "Word" );
 	if (mode)
 		Word->setEnabled(false);
@@ -258,7 +257,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	OptsLayout->addWidget( CaseIgnore );
 	SearchReplaceLayout->addLayout( OptsLayout );
 
-	ButtonsLayout = new QHBoxLayout( 0, 0, 4, "ButtonsLayout"); 
+	ButtonsLayout = new QHBoxLayout( 0, 0, 4, "ButtonsLayout");
 	DoSearch = new QPushButton( tr( "&Search" ), this, "DoSearch" );
 	DoSearch->setDefault( true );
 	ButtonsLayout->addWidget( DoSearch );
@@ -268,7 +267,7 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	AllReplace = new QPushButton( tr( "Replace &All" ), this, "DoReplace" );
 	AllReplace->setEnabled(false);
 	ButtonsLayout->addWidget( AllReplace );
-	clearButton = new QPushButton(tr("C&lear"), this, "clearButton");
+	clearButton = new QPushButton( tr("C&lear"), this, "clearButton");
 	ButtonsLayout->addWidget(clearButton);
 	Leave = new QPushButton( tr( "&Close" ), this, "Leave" );
 	ButtonsLayout->addWidget( Leave );
@@ -335,20 +334,20 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, preV *Prefs, Pag
 	setTabOrder( DoSearch, DoReplace );
 	setTabOrder( DoReplace, AllReplace );
 	setTabOrder( AllReplace, Leave );
-	
-	prefs = prefsFile->getContext("SearchReplace");
+
+	prefs = PrefsManager::instance()->prefsFile->getContext("SearchReplace");
 	readPrefs();
 }
 
 void SearchReplace::slotSearch()
 {
 	if (SMode)
-		Doc->ActPage->slotDoCurs(false);
+		ScMW->view->slotDoCurs(false);
 	slotDoSearch();
 	if (SMode)
 	{
-		Doc->ActPage->slotDoCurs(true);
-		Doc->ActPage->RefreshItem(Item, true);
+		ScMW->view->slotDoCurs(true);
+		ScMW->view->RefreshItem(Item);
 	}
 }
 
@@ -358,8 +357,8 @@ void SearchReplace::slotDoSearch()
 	AllReplace->setEnabled(false);
 	if (SMode)
 	{
-		for (uint a = 0; a < Item->Ptext.count(); ++a)
-			Item->Ptext.at(a)->cselect = false;
+		for (uint a = 0; a < Item->itemText.count(); ++a)
+			Item->itemText.at(a)->cselect = false;
 		Item->HasSel = false;
 	}
 	QString fCol = "";
@@ -406,11 +405,11 @@ void SearchReplace::slotDoSearch()
 	uint a;
 	if (SMode)
 	{
-		for (a = as; a < Item->Ptext.count(); ++a)
+		for (a = as; a < Item->itemText.count(); ++a)
 		{
 			if (SText->isChecked())
 			{
-				QString chx = Item->Ptext.at(a)->ch;
+				QString chx = Item->itemText.at(a)->ch;
 				if (CaseIgnore->isChecked())
 					chx = chx.lower();
 				found = chx == sText.mid(inde, 1) ? true : false;
@@ -421,47 +420,47 @@ void SearchReplace::slotDoSearch()
 				found = true;
 			if (SSize->isChecked())
 			{
-				if (Item->Ptext.at(a)->csize != sSize)
+				if (Item->itemText.at(a)->csize != sSize)
 					found = false;
 			}
 			if (SFont->isChecked())
 			{
-				if (Item->Ptext.at(a)->cfont != sFont)
+				if (Item->itemText.at(a)->cfont->scName() != sFont)
 					found = false;
 			}
 			if (SStyle->isChecked())
 			{
-				if (Item->Ptext.at(a)->cab != sStyle)
+				if (Item->itemText.at(a)->cab != sStyle)
 					found = false;
 			}
 			if (SStroke->isChecked())
 			{
-				if (Item->Ptext.at(a)->cstroke != sCol)
+				if (Item->itemText.at(a)->cstroke != sCol)
 					found = false;
 			}
 			if (SStrokeS->isChecked())
 			{
-				if (Item->Ptext.at(a)->cshade2 != sStrokeSh)
+				if (Item->itemText.at(a)->cshade2 != sStrokeSh)
 					found = false;
 			}
 			if (SFillS->isChecked())
 			{
-				if (Item->Ptext.at(a)->cshade != sFillSh)
+				if (Item->itemText.at(a)->cshade != sFillSh)
 					found = false;
 			}
 			if (SEffect->isChecked())
-				{
-				if ((Item->Ptext.at(a)->cstyle & 127) != sEff)
+			{
+				if ((Item->itemText.at(a)->cstyle & 1919) != sEff)
 					found = false;
-				}
+			}
 			if (SFill->isChecked())
-			{			
-				if (Item->Ptext.at(a)->ccolor != fCol)
+			{
+				if (Item->itemText.at(a)->ccolor != fCol)
 					found = false;
 			}
 			if (found)
 			{
-				Item->Ptext.at(a)->cselect = true;
+				Item->itemText.at(a)->cselect = true;
 				Item->HasSel = true;
 				if (rep)
 				{
@@ -474,16 +473,16 @@ void SearchReplace::slotDoSearch()
 					if (inde == 0)
 						ReplStart = a;
 					inde++;
-					if ((Word->isChecked()) && (inde == 1) && (Item->Ptext.at(a)->ch[0].isSpace()))
+					if ((Word->isChecked()) && (inde == 1) && (Item->itemText.at(a)->ch[0].isSpace()))
 					{
 						inde--;
-						Item->Ptext.at(a)->cselect = false;
+						Item->itemText.at(a)->cselect = false;
 					}
 					if ((Word->isChecked()) && (inde == sText.length()) &&
-						(!Item->Ptext.at(QMIN(Item->MaxChars-1,a+1))->ch[0].isSpace()))
+						(!Item->itemText.at(QMIN(Item->MaxChars-1,a+1))->ch[0].isSpace()))
 					{
 						for (uint xx = ReplStart; xx < a+1; ++xx)
-							Item->Ptext.at(QMIN(xx,Item->MaxChars-1))->cselect = false;
+							Item->itemText.at(QMIN(xx,Item->MaxChars-1))->cselect = false;
 						Item->HasSel = false;
 						inde = 0;
 						found = false;
@@ -502,58 +501,55 @@ void SearchReplace::slotDoSearch()
 				if (SText->isChecked())
 				{
 					for (uint xx = ReplStart; xx < a+1; ++xx)
-						Item->Ptext.at(QMIN(xx,Item->MaxChars-1))->cselect = false;
+						Item->itemText.at(QMIN(xx,Item->MaxChars-1))->cselect = false;
 					Item->HasSel = false;
 				}
 				inde = 0;
 			}
 		}
-		if ((!found) || (a == Item->Ptext.count()))
+		if ((!found) || (a == Item->itemText.count()))
 		{
 			Doc->DoDrawing = true;
-			Doc->ActPage->RefreshItem(Item, true);
+			ScMW->view->RefreshItem(Item);
 			DoReplace->setEnabled(false);
 			AllReplace->setEnabled(false);
-			QMessageBox::information(this, tr("Search/Replace"), tr("Search finished"), tr("OK"));
+			QMessageBox::information(this, tr("Search/Replace"), tr("Search finished"), CommonStrings::tr_OK);
 			Item->CPos = 0;
 			NotFound = false;
 		}
 	}
 	else
 	{
-		if (ScApp->CurrStED != NULL)
+		if (ScMW->CurrStED != NULL)
 		{
 			int p, i;
-			ScApp->CurrStED->Editor->getCursorPosition(&p, &i);
+			ScMW->CurrStED->Editor->getCursorPosition(&p, &i);
 			uint inde = 0;
 			int as = i;
 			uint fpa = p;
 			int fch = i;
 			found = false;
-			if (ScApp->CurrStED->Editor->StyledText.count() != 0)
+			if (ScMW->CurrStED->Editor->StyledText.count() != 0)
 			{
-				for (uint pa = p; pa < ScApp->CurrStED->Editor->StyledText.count(); ++pa)
+				for (uint pa = p; pa < ScMW->CurrStED->Editor->StyledText.count(); ++pa)
 				{
 					SEditor::ChList *chars;
-					chars = ScApp->CurrStED->Editor->StyledText.at(pa);
+					chars = ScMW->CurrStED->Editor->StyledText.at(pa);
 					if (SText->isChecked())
 					{
+						QString para = ScMW->CurrStED->Editor->text(pa);
+						if (CaseIgnore->isChecked())
+							para = para.lower();
 						if (Word->isChecked())
 						{
 							QRegExp rx( "(\\b"+sText+"\\b)" );
-							if (CaseIgnore->isChecked())
-								as = rx.search( ScApp->CurrStED->Editor->text(pa).lower(), i );
-							else
-								as = rx.search( ScApp->CurrStED->Editor->text(pa), i );
+							as = rx.search( para, i );
 						}
 						else
-						{
-							if (CaseIgnore->isChecked())
-								as = ScApp->CurrStED->Editor->text(pa).lower().find(sText, i);
-							else
-								as = ScApp->CurrStED->Editor->text(pa).find(sText, i);
-						}
-						if (as != -1)
+							as = para.find(sText, i);
+						// #6688 : it's necessary to control chars->count() as QTextExit::text(int)
+						// may return paragraph text with an appended space
+						if (as != -1 && (as < (int) chars->count()))
 						{
 							fch = as;
 							fpa = pa;
@@ -575,7 +571,7 @@ void SearchReplace::slotDoSearch()
 									found = false;
 								if ((SFillS->isChecked()) && (hg->cshade != sFillSh))
 									found = false;
-								if ((SEffect->isChecked()) && ((hg->cstyle & 127) != sEff))
+								if ((SEffect->isChecked()) && ((hg->cstyle & 1919) != sEff))
 									found = false;
 								if ((SFill->isChecked()) && (hg->ccolor != fCol))
 									found = false;
@@ -611,7 +607,7 @@ void SearchReplace::slotDoSearch()
 								found = false;
 							if ((SFillS->isChecked()) && (hg->cshade != sFillSh))
 								found = false;
-							if ((SEffect->isChecked()) && ((hg->cstyle & 127) != sEff))
+							if ((SEffect->isChecked()) && ((hg->cstyle & 1919) != sEff))
 								found = false;
 							if ((SFill->isChecked()) && (hg->ccolor != fCol))
 								found = false;
@@ -630,21 +626,25 @@ void SearchReplace::slotDoSearch()
 				}
 				if (found)
 				{
-					ScApp->CurrStED->Editor->setSelection(fpa, fch, fpa, fch+inde);
-					ScApp->CurrStED->updateProps(fpa, fch);
-					ScApp->CurrStED->Editor->setCursorPosition(fpa, fch+inde);
+					ScMW->CurrStED->Editor->setSelection(fpa, fch, fpa, fch+inde);
+					ScMW->CurrStED->updateProps(fpa, fch);
+					ScMW->CurrStED->Editor->setCursorPosition(fpa, fch+inde);
 					if (rep)
 					{
 						DoReplace->setEnabled(true);
 						AllReplace->setEnabled(true);
 					}
+					matchesFound++;
 				}
 				else
 				{
-					QMessageBox::information(this, tr("Search/Replace"), tr("Search finished"), tr("OK"));
+					QMessageBox::information(this, tr("Search/Replace"),
+							tr("Search finished, found %1 matches").arg(matchesFound),
+							CommonStrings::tr_OK);
+					matchesFound = 0;
 					NotFound = false;
-					ScApp->CurrStED->Editor->removeSelection();
-					ScApp->CurrStED->Editor->setCursorPosition(0, 0);
+					ScMW->CurrStED->Editor->removeSelection();
+					ScMW->CurrStED->Editor->setCursorPosition(0, 0);
 				}
 			}
 		}
@@ -654,12 +654,12 @@ void SearchReplace::slotDoSearch()
 void SearchReplace::slotReplace()
 {
 	if (SMode)
-		Doc->ActPage->slotDoCurs(false);
+		ScMW->view->slotDoCurs(false);
 	slotDoReplace();
 	if (SMode)
 	{
-		Doc->ActPage->slotDoCurs(true);
-		Doc->ActPage->RefreshItem(Item, true);
+		ScMW->view->slotDoCurs(true);
+		ScMW->view->RefreshItem(Item);
 	}
 }
 
@@ -669,7 +669,7 @@ void SearchReplace::slotDoReplace()
 	{
 		QString repl, sear;
 		uint cs, cx;
-		struct Pti *hg;
+		ScText *hg;
 		if (RText->isChecked())
 		{
 			repl = RTextVal->text();
@@ -677,17 +677,17 @@ void SearchReplace::slotDoReplace()
 			if (sear.length() == repl.length())
 			{
 				for (cs = 0; cs < sear.length(); ++cs)
-					Item->Ptext.at(ReplStart+cs)->ch = repl[cs];
+					Item->itemText.at(ReplStart+cs)->ch = repl[cs];
 			}
 			else
 			{
 				if (sear.length() < repl.length())
 				{
 					for (cs = 0; cs < sear.length(); ++cs)
-						Item->Ptext.at(ReplStart+cs)->ch = repl[cs];
+						Item->itemText.at(ReplStart+cs)->ch = repl[cs];
 					for (cx = cs; cx < repl.length(); ++cx)
 					{
-						hg = new Pti;
+						hg = new ScText;
 						hg->ch = repl[cx];
 						if (RSize->isChecked())
 							hg->csize = qRound(RSizeVal->value() * 10.0);
@@ -704,38 +704,47 @@ void SearchReplace::slotDoReplace()
 							hg->cstroke = Doc->CurrTextStroke;
 						hg->cshade2 = Doc->CurrTextStrokeSh;
 						hg->cscale = Doc->CurrTextScale;
+						hg->cbase = Doc->CurrTextBase;
+						hg->cshadowx = Doc->CurrTextShadowX;
+						hg->cshadowy = Doc->CurrTextShadowY;
+						hg->coutline = Doc->CurrTextOutline;
+						hg->cunderpos = Doc->CurrTextUnderPos;
+						hg->cunderwidth = Doc->CurrTextUnderWidth;
+						hg->cstrikepos = Doc->CurrTextStrikePos;
+						hg->cstrikewidth = Doc->CurrTextStrikeWidth;
+						hg->cembedded = 0;
 						hg->cselect = true;
 						hg->cstyle = Doc->CurrentStyle;
 						if (RStyle->isChecked())
 							hg->cab = RStyleVal->currentItem();
 						else
-							hg->cab = Doc->CurrentABStil;
-						if (Doc->Vorlagen[hg->cab].Font != "")
+							hg->cab = Doc->currentParaStyle;
+						if (!Doc->docParagraphStyles[hg->cab].Font.isEmpty())
 						{
-							hg->cfont = Doc->Vorlagen[hg->cab].Font;
-							hg->csize = Doc->Vorlagen[hg->cab].FontSize;
-							hg->cstyle = Doc->Vorlagen[hg->cab].FontEffect;
+							hg->cfont = (*Doc->AllFonts)[Doc->docParagraphStyles[hg->cab].Font];
+							hg->csize = Doc->docParagraphStyles[hg->cab].FontSize;
+							hg->cstyle = Doc->docParagraphStyles[hg->cab].FontEffect;
 						}
 						if (RFont->isChecked())
-							hg->cfont = RFontVal->currentText();
+							hg->cfont = (*Doc->AllFonts)[RFontVal->currentText()];
 						else
-							hg->cfont = Doc->CurrFont;
+							hg->cfont = (*Doc->AllFonts)[Doc->CurrFont];
 						hg->cextra = 0;
 						hg->xp = 0;
 						hg->yp = 0;
 						hg->PRot = 0;
 						hg->PtransX = 0;
 						hg->PtransY = 0;
-						Item->Ptext.insert(ReplStart+cx, hg);     
+						Item->itemText.insert(ReplStart+cx, hg);
 					}
 					Item->CPos = ReplStart+cx;
 				}
 				else
 				{
 					for (cs = 0; cs < repl.length(); ++cs)
-						Item->Ptext.at(ReplStart+cs)->ch = repl[cs];
+						Item->itemText.at(ReplStart+cs)->ch = repl[cs];
 					for (uint cxx = cs; cxx < sear.length(); ++cxx)
-						Item->Ptext.remove(ReplStart+cs);
+						Item->itemText.remove(ReplStart+cs);
 					Item->CPos = ReplStart+cs;
 				}
 			}
@@ -743,82 +752,85 @@ void SearchReplace::slotDoReplace()
 		if (RStyle->isChecked())
 			emit NewAbs(RStyleVal->currentItem());
 		if (RFill->isChecked())
-			Doc->ActPage->ItemTextBrush(RFillVal->currentText());
+			Doc->ItemTextBrush(RFillVal->currentText());
 		if (RFillS->isChecked())
-			Doc->ActPage->ItemTextBrushS(RFillSVal->getValue());
+			Doc->ItemTextBrushS(RFillSVal->getValue());
 		if (RStroke->isChecked())
-			Doc->ActPage->ItemTextPen(RStrokeVal->currentText());
+			Doc->ItemTextPen(RStrokeVal->currentText());
 		if (RStrokeS->isChecked())
-			Doc->ActPage->ItemTextPenS(RStrokeSVal->getValue());
+			Doc->ItemTextPenS(RStrokeSVal->getValue());
 		if (RFont->isChecked())
 			emit NewFont(RFontVal->currentText());
 		if (RSize->isChecked())
-			Doc->ActPage->chFSize(qRound(RSizeVal->value() * 10.0));
+			Doc->chFSize(qRound(RSizeVal->value() * 10.0));
 		if (REffect->isChecked())
-			{
+		{
 			int s = REffVal->getStyle();
 			Doc->CurrentStyle = s;
-			if (Item->Ptext.count() != 0)
+			if (Item->itemText.count() != 0)
+			{
+				for (uint a = 0; a < Item->itemText.count(); ++a)
 				{
-				for (uint a = 0; a < Item->Ptext.count(); ++a)
+					if (Item->itemText.at(a)->cselect)
 					{
-					if (Item->Ptext.at(a)->cselect)
-						{
-						Item->Ptext.at(a)->cstyle &= ~127;
-						Item->Ptext.at(a)->cstyle |= s;
-						}
+						Item->itemText.at(a)->cstyle &= ~1919;
+						Item->itemText.at(a)->cstyle |= s;
 					}
 				}
 			}
-		for (uint a = 0; a < Item->Ptext.count(); ++a)
-			Item->Ptext.at(a)->cselect = false;
+		}
+		for (uint a = 0; a < Item->itemText.count(); ++a)
+			Item->itemText.at(a)->cselect = false;
 	}
 	else
 	{
-		if (ScApp->CurrStED != NULL)
+		if (ScMW->CurrStED != NULL)
 		{
 			if (RStyle->isChecked())
-				ScApp->CurrStED->newAlign(RStyleVal->currentItem());
+				ScMW->CurrStED->newAlign(RStyleVal->currentItem());
 			if (RFill->isChecked())
-				ScApp->CurrStED->newTxFill(RFillVal->currentItem(), -1);
+				ScMW->CurrStED->newTxFill(RFillVal->currentItem(), -1);
 			if (RFillS->isChecked())
-				ScApp->CurrStED->newTxFill(-1, RFillSVal->getValue());
+				ScMW->CurrStED->newTxFill(-1, RFillSVal->getValue());
 			if (RStroke->isChecked())
-				ScApp->CurrStED->newTxStroke(RStrokeVal->currentItem(), -1);
+				ScMW->CurrStED->newTxStroke(RStrokeVal->currentItem(), -1);
 			if (RStrokeS->isChecked())
-				ScApp->CurrStED->newTxStroke(-1, RStrokeSVal->getValue());
+				ScMW->CurrStED->newTxStroke(-1, RStrokeSVal->getValue());
 			if (RFont->isChecked())
-				ScApp->CurrStED->newTxFont(RFontVal->currentText());
+				ScMW->CurrStED->newTxFont(RFontVal->currentText());
 			if (RSize->isChecked())
-				ScApp->CurrStED->newTxSize(RSizeVal->value());
+				ScMW->CurrStED->newTxSize(RSizeVal->value());
 			if (REffect->isChecked())
-				ScApp->CurrStED->newTxStyle(REffVal->getStyle());
+				ScMW->CurrStED->newTxStyle(REffVal->getStyle());
 			if (RText->isChecked())
 			{
-				disconnect(ScApp->CurrStED->Editor, SIGNAL(cursorPositionChanged(int, int)), ScApp->CurrStED, SLOT(updateProps(int, int)));
+				disconnect(ScMW->CurrStED->Editor, SIGNAL(cursorPositionChanged(int, int)), ScMW->CurrStED, SLOT(updateProps(int, int)));
 				int PStart, PEnd, SelStart, SelEnd;
-				ScApp->CurrStED->Editor->getSelection(&PStart, &SelStart, &PEnd, &SelEnd);
-				ScApp->CurrStED->Editor->insChars(RTextVal->text());
-				ScApp->CurrStED->Editor->setSelection(PStart, SelStart, PEnd, SelEnd);
-				ScApp->CurrStED->Editor->removeSelectedText();
-				ScApp->CurrStED->Editor->setStyle(ScApp->CurrStED->Editor->CurrentStyle);
-				ScApp->CurrStED->Editor->setFarbe(ScApp->CurrStED->Editor->CurrTextFill, ScApp->CurrStED->Editor->CurrTextFillSh);
-				ScApp->CurrStED->Editor->insert(RTextVal->text());
-				connect(ScApp->CurrStED->Editor, SIGNAL(cursorPositionChanged(int, int)), ScApp->CurrStED, SLOT(updateProps(int, int)));
-				ScApp->CurrStED->newAlign(ScApp->CurrStED->Editor->CurrentABStil);
+				// #6688 : QTextExit::getSelection() may return sometime a truly empty selection,
+				// so check that PStart != PEnd || SelStart != SelEnd
+				ScMW->CurrStED->Editor->getSelection(&PStart, &SelStart, &PEnd, &SelEnd);
+				if ((PStart != PEnd) || (SelStart != SelEnd))
+				{
+					ScMW->CurrStED->Editor->removeSelectedText();
+					ScMW->CurrStED->Editor->setStyle(ScMW->CurrStED->Editor->CurrentStyle);
+					ScMW->CurrStED->Editor->insChars(RTextVal->text(), PStart, SelStart, true); 
+					ScMW->CurrStED->Editor->insert(RTextVal->text(), PStart, SelStart, false);
+				}
+				connect(ScMW->CurrStED->Editor, SIGNAL(cursorPositionChanged(int, int)), ScMW->CurrStED, SLOT(updateProps(int, int)));
+				ScMW->CurrStED->newAlign(ScMW->CurrStED->Editor->currentParaStyle);
 			}
 		}
 	}
 	DoReplace->setEnabled(false);
 	AllReplace->setEnabled(false);
-		slotDoSearch();
+	slotDoSearch();
 }
 
 void SearchReplace::slotReplaceAll()
 {
 	if (SMode)
 	{
-		Doc->ActPage->slotDoCurs(false);
+		ScMW->view->slotDoCurs(false);
 		Doc->DoDrawing = false;
 	}
 	do
@@ -830,8 +842,8 @@ void SearchReplace::slotReplaceAll()
 	if (SMode)
 	{
 		Doc->DoDrawing = true;
-		Doc->ActPage->slotDoCurs(true);
-		Doc->ActPage->RefreshItem(Item, true);
+		ScMW->view->slotDoCurs(true);
+		ScMW->view->RefreshItem(Item);
 	}
 }
 
@@ -946,7 +958,7 @@ void SearchReplace::clear()
 	SEffect->setChecked(false);
 	REffect->setChecked(false);
 	STextVal->setText("");
-	SStyleVal->setCurrentItem(Doc->CurrentABStil);
+	SStyleVal->setCurrentItem(Doc->currentParaStyle);
 	SFontVal->setCurrentText(Doc->CurrFont);
 	SSizeVal->setValue(Doc->CurrFontSize / 10.0);
 	SFillVal->setCurrentText(Doc->CurrTextFill);
@@ -960,7 +972,7 @@ void SearchReplace::clear()
 	RStyle->setChecked(false);
 	RText->setChecked(false);
 	RTextVal->setText("");
-	RStyleVal->setCurrentItem(Doc->CurrentABStil);
+	RStyleVal->setCurrentItem(Doc->currentParaStyle);
 	RFontVal->setCurrentText(Doc->CurrFont);
 	RSizeVal->setValue(Doc->CurrFontSize / 10.0);
 	RFillVal->setCurrentText(Doc->CurrTextFill);
@@ -1000,7 +1012,7 @@ void SearchReplace::readPrefs()
 	SEffect->setChecked(prefs->getBool("SEffect", false));
 	REffect->setChecked(prefs->getBool("REffect", false));
 	STextVal->setText(prefs->get("STextVal", ""));
-	int tmp = prefs->getInt("SStyleVal", Doc->CurrentABStil);
+	int tmp = prefs->getInt("SStyleVal", Doc->currentParaStyle);
 	if (tmp < 0 || tmp >= SStyleVal->count())
 		SStyleVal->setCurrentItem(0);
 	else
@@ -1019,7 +1031,7 @@ void SearchReplace::readPrefs()
 	RStyle->setChecked(prefs->getBool("RStyle", false));
 	RText->setChecked(prefs->getBool("RText", false));
 	RTextVal->setText(prefs->get("RTextVal", ""));
-	tmp = prefs->getInt("RStyleVal", Doc->CurrentABStil);
+	tmp = prefs->getInt("RStyleVal", Doc->currentParaStyle);
 	if (tmp < 0 || tmp >= RStyleVal->count())
 		RStyleVal->setCurrentItem(0);
 	else
