@@ -47,6 +47,7 @@ for which a new license (GPL+exception) is in place.
 #include "scribusapi.h"
 #include "pageitem.h"
 
+class QMimeSource;
 class MenuManager;
 class MSpinBox;
 class Spalette;
@@ -102,8 +103,9 @@ public:
 	void deleteSel();
 	void setStyle(int Csty);
 	void setFarbe(bool marker);
-	void insChars(QString t);
-	void insStyledText(int *newParaCount, int *lengthLastPara);		
+	void insChars(const QString& t);
+	void insChars(const QString& t, int& para, int& index, bool delSel);
+	void insStyledText(QMimeSource* storyData, int *newParaCount, int *lengthLastPara);		
 	void copyStyledText();
 
 	typedef QPtrList<PtiSmall> ChList;
@@ -136,9 +138,6 @@ public:
 	QString prevFont;
 	QString CurrFont;
 	QString unicodeInputString;
-	QString tBuffer;
-	ChList cBuffer;
-	int ClipData;
 	bool StoredSel;
 	int SelParaStart;
 	int SelParaEnd;
@@ -467,3 +466,5 @@ protected:
 
 #endif
 
+
+
