@@ -37,7 +37,7 @@ TabPDFOptions::TabPDFOptions(   QWidget* parent, PDFOptions & Optionen,
                                 const QMap<QString,int> & DocFonts,
                                 const QValueList<PDFPresentationData> & Eff,
                                 int unitIndex, double PageH, double PageB,
-                                ScribusView * vie )
+                                ScribusView * vie, bool prefsMode )
 	: QTabWidget( parent, "pdf" ),
 	// Initialize all those darn pointer members so we catch unitialized
 	// accesses. I (CR) use the following command to generate these based on
@@ -230,7 +230,8 @@ TabPDFOptions::TabPDFOptions(   QWidget* parent, PDFOptions & Optionen,
 	Opts(Optionen),
 	pageH(PageH),
 	pageB(PageB),
-	cms(false)
+	cms(false),
+	m_prefsMode(prefsMode)
 {
 
 	tabGeneral = new QWidget( this, "tabGeneral" );
@@ -650,8 +651,7 @@ TabPDFOptions::TabPDFOptions(   QWidget* parent, PDFOptions & Optionen,
 		EDirection_2_2->setEditable(false);
 		TextLabel6e->setBuddy(EDirection_2_2);
 		EffectsLayout->addWidget( EDirection_2_2, 5, 1 );
-		EonAllPg = new QPushButton( tr( "&Apply Effect on all Pages" ), Effects, "Eon" );
-		//revert for 13311 EonAllPg = new QPushButton( tr( "&Apply Effect to all Pages" ), Effects, "Eon" );
+		EonAllPg = new QPushButton( tr( "&Apply Effect to all Pages" ), Effects, "Eon" );
 		EffectsLayout->addMultiCellWidget( EonAllPg, 6, 6, 0, 1 );
 		tabLayout_5->addMultiCellWidget( Effects, 1, 2, 1, 1 );
 		insertTab( tabPresentation, tr( "E&xtras" ) );
@@ -919,6 +919,12 @@ TabPDFOptions::TabPDFOptions(   QWidget* parent, PDFOptions & Optionen,
 	tabColorLayout->addWidget( LPIgroup );
 	SelLPIcolor = LPIcolor->currentText();
 
+	if (m_prefsMode)
+	{
+		UseLPI->hide();
+		LPIgroup->hide();
+	}
+
 	GroupBox9 = new QGroupBox( tr( "Solid Colors:" ), tabColor, "GroupBox9" );
 	GroupBox9->setColumnLayout(0, Qt::Vertical );
 	GroupBox9->layout()->setSpacing( 5 );
@@ -1464,11 +1470,14 @@ void TabPDFOptions::EnableLPI(int a)
 			GroupBox9->hide();
 			ProfsGroup->hide();
 			useSpot->show();
-			UseLPI->show();
-			if (UseLPI->isChecked())
-				LPIgroup->show();
-			else
-				LPIgroup->hide();
+			if (!m_prefsMode)
+			{
+				UseLPI->show();
+				if (UseLPI->isChecked())
+					LPIgroup->show();
+				else
+					LPIgroup->hide();
+			}
 		}
 	}
 	else
@@ -1481,10 +1490,13 @@ void TabPDFOptions::EnableLPI(int a)
 
 void TabPDFOptions::EnableLPI2()
 {
-	if (UseLPI->isChecked())
-		LPIgroup->show();
-	else
-		LPIgroup->hide();
+	if (!m_prefsMode)
+	{
+		if (UseLPI->isChecked())
+			LPIgroup->show();
+		else
+			LPIgroup->hide();
+	}
 }
 
 void TabPDFOptions::SelLPIcol(int c)
